@@ -15,5 +15,6 @@
 #
 
 from ._base import Document, Generator, IndexTerm, Posting, IndexReader
+from ._indexer import LuceneIndexer
 
-__all__ = ['Document', 'Generator', 'IndexTerm', 'Posting', 'IndexReader']
\ No newline at end of file
+__all__ = ['Document', 'Generator', 'IndexTerm', 'Posting', 'IndexReader', 'LuceneIndexer']
\ No newline at end of file
